@@ -14,17 +14,28 @@ from mobster.utils_mobster import *
 from mobster.stopping_criteria import *
 import mobster.model_selection_mobster as ms
 from mobster.calculate_posteriors import *
+from pyro.util import ignore_jit_warnings
+
 
 def fit_mobster(data, K, tail=1, purity=0.96,alpha_prior_concentration = 5, alpha_prior_rate = 10, number_of_trials_clonal_mean=500.,number_of_trials_k=300.,
-         prior_lims_clonal=[0.1, 100000.], prior_lims_k=[0.1, 100000.], stopping = ELBO_stopping_criteria, lr = 0.05, max_it = 5000, e = 0.001):
+         prior_lims_clonal=[0.1, 100000.], prior_lims_k=[0.1, 100000.], stopping = ELBO_stopping_criteria, lr = 0.05, max_it = 5000, e = 0.001, compile = False, CUDA = False):
+
+
+    if CUDA:
+        torch.set_default_tensor_type('torch.cuda.FloatTensor')
+
+    if compile:
+        loss = pyro.infer.JitTraceGraph_ELBO
+    else:
+        loss = pyro.infer.TraceGraph_ELBO
 
     model = mobster.model
     guide = mobster.guide
 
     svi = pyro.infer.SVI(model=model,
                      guide=guide,
-                     optim=pyro.optim.Adam({"lr": lr}),
-                     loss=pyro.infer.TraceGraph_ELBO())
+                     optim=pyro.optim.ClippedAdam({"lr": lr}),
+                     loss= loss())
 
     print('Running MOBSTER on {} karyotypes with {} subclones.'.format(len(data), K), flush=True)
     if tail == 1:
